@@ -96,8 +96,7 @@ class SpeechMixEED(nn.Module):
                                                    self.decoder_model.config.decoder_start_token_id)
         encoder_outputs = self.encoder_model(input_values=input_values, attention_mask=attention_mask)
         inputs_embeds = encoder_outputs['last_hidden_state']
-        downsamp_mask = self.encoder_model._get_feature_vector_attention_mask(
-            encoder_outputs['extract_features'].shape[1], attention_mask)
+        downsamp_mask = self.encoder_model._get_feature_vector_attention_mask(inputs_embeds.shape[1], attention_mask)
         downsamp_mask = (torch.sum(downsamp_mask, dim=-1) / self.downsize).int().tolist()
         downsamp_mask = torch.nn.utils.rnn.pad_sequence([torch.tensor([1] * i) for i in downsamp_mask],
                                                         batch_first=True).to(self.device)
@@ -123,8 +122,7 @@ class SpeechMixSelf(SpeechMixEED):
                                                    self.decoder_model.config.decoder_start_token_id)
         encoder_outputs = self.encoder_model(input_values=input_values, attention_mask=attention_mask)
         inputs_embeds = encoder_outputs['last_hidden_state']
-        downsamp_mask = self.encoder_model._get_feature_vector_attention_mask(
-            encoder_outputs['extract_features'].shape[1], attention_mask)
+        downsamp_mask = self.encoder_model._get_feature_vector_attention_mask(inputs_embeds.shape[1], attention_mask)
         downsamp_mask = (torch.sum(downsamp_mask, dim=-1) / self.downsize).int().tolist()
         downsamp_mask = torch.nn.utils.rnn.pad_sequence([torch.tensor([1] * i) for i in downsamp_mask],
                                                         batch_first=True).to(self.device)
